@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2013 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2014 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -261,7 +261,7 @@ def print_version():
     print """
 %s-%s
 
-Copyright (C) 2008-2013, The SABnzbd-Team <team@sabnzbd.org>
+Copyright (C) 2008-2014, The SABnzbd-Team <team@sabnzbd.org>
 SABnzbd comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions. It is licensed under the
@@ -1295,6 +1295,24 @@ def main():
             logging.debug('Could not determine my IPv6 address')
             pass
 
+        # measure and log Pystone performance, and - if possible - CPU type
+        try:
+            # First try pystone from Python test libary
+            from test.pystone import pystones
+        except:
+            # otherwise use the one provided by SABnzbd
+            from util.pystone import pystones
+        pystonetime,pystoneperformance = pystones(1000)
+        logging.debug('CPU Pystone available performance is %s',int(pystoneperformance))
+        try:	
+            for myline in open("/proc/cpuinfo"):
+                if myline.startswith(('model name')):
+                    logging.debug('CPU model name is %s', myline[13:].rstrip() )
+                    break
+        except:
+            # probably not on Linux
+            pass
+
     # OSX 10.5 I/O priority setting
     if sabnzbd.DARWIN:
         logging.info('[osx] IO priority setting')
