@@ -30,6 +30,7 @@ import gzip
 import subprocess
 import time
 import cherrypy
+import sys
 from threading import RLock, Lock, Condition, Thread
 try:
     import sleepless
@@ -61,12 +62,13 @@ elif os.name == 'posix':
             FOUNDATION = True
         except:
             pass
-        if platform.machine() == 'i386':
+        if '86' in platform.machine():
             DARWIN_INTEL = True
 if DARWIN:
+    DARWIN_YS = [int(n) for n in platform.mac_ver()[0].split('.')] >= [10, 9]
     DARWIN_ML = [int(n) for n in platform.mac_ver()[0].split('.')] >= [10, 8]
 else:
-    DARWIN_ML = False
+    DARWIN_YS = DARWIN_ML = False
 
 #------------------------------------------------------------------------
 
@@ -959,7 +961,8 @@ def load_admin(_id, remove=False, do_pickle=True):
         if remove:
             os.remove(path)
     except:
-        logging.error(Ta('Loading %s failed'), path)
+        excepterror = str(sys.exc_info()[0])
+        logging.error(Ta('Loading %s failed with error %s'), path, excepterror)
         logging.info("Traceback: ", exc_info = True)
         return None
 
