@@ -115,9 +115,26 @@ bookmark_rate = OptionNumber('newzbin', 'bookmark_rate', 60, minval=15, maxval=2
 newzbin_url = OptionStr('newzbin', 'url', 'www.newzbin2.es')
 
 rating_enable = OptionBool('misc', 'rating_enable', False)
-rating_host = OptionStr('misc', 'rating_host', 'www.oznzb.com')
+rating_host = OptionStr('misc', 'rating_host', 'api.oznzb.com')
 rating_api_key = OptionStr('misc', 'rating_api_key')
 rating_feedback = OptionBool('misc', 'rating_feedback', True)
+rating_filter_enable = OptionBool('misc', 'rating_filter_enable', False)
+rating_filter_abort_audio = OptionNumber('misc', 'rating_filter_abort_audio', 0)
+rating_filter_abort_video = OptionNumber('misc', 'rating_filter_abort_video', 0)
+rating_filter_abort_encrypted = OptionBool('misc', 'rating_filter_abort_encrypted', False)
+rating_filter_abort_encrypted_confirm = OptionBool('misc', 'rating_filter_abort_encrypted_confirm', False)
+rating_filter_abort_spam = OptionBool('misc', 'rating_filter_abort_spam', False)
+rating_filter_abort_spam_confirm = OptionBool('misc', 'rating_filter_abort_spam_confirm', False)
+rating_filter_abort_downvoted = OptionBool('misc', 'rating_filter_abort_downvoted', False)
+rating_filter_abort_keywords = OptionStr('misc', 'rating_filter_abort_keywords')
+rating_filter_pause_audio = OptionNumber('misc', 'rating_filter_pause_audio', 0)
+rating_filter_pause_video = OptionNumber('misc', 'rating_filter_pause_video', 0)
+rating_filter_pause_encrypted = OptionBool('misc', 'rating_filter_pause_encrypted', False)
+rating_filter_pause_encrypted_confirm = OptionBool('misc', 'rating_filter_pause_encrypted_confirm', False)
+rating_filter_pause_spam = OptionBool('misc', 'rating_filter_pause_spam', False)
+rating_filter_pause_spam_confirm = OptionBool('misc', 'rating_filter_pause_spam_confirm', False)
+rating_filter_pause_downvoted = OptionBool('misc', 'rating_filter_pause_downvoted', False)
+rating_filter_pause_keywords = OptionStr('misc', 'rating_filter_pause_keywords')
 
 top_only = OptionBool('misc', 'top_only', False)
 autodisconnect = OptionBool('misc', 'auto_disconnect', True)
