@@ -43,6 +43,7 @@ PNFO_MISSING_FIELD = 18
 QNFO_BYTES_FIELD = 0
 QNFO_BYTES_LEFT_FIELD = 1
 QNFO_PNFO_LIST_FIELD = 2
+QNFO_Q_SIZE_LIST_FIELD = 3
 
 ANFO_ARTICLE_SUM_FIELD = 0
 ANFO_CACHE_SIZE_FIELD = 1
@@ -64,6 +65,7 @@ FUTURE_Q_FOLDER   = 'future'
 JOB_ADMIN = '__ADMIN__'
 VERIFIED_FILE = '__verified__'
 QCHECK_FILE = '__skip_qcheck__'
+RENAMES_FILE = '__renames__'
 ATTRIB_FILE = 'SABnzbd_attrib'
 REPAIR_REQUEST = 'repair-all.sab'
 
@@ -157,3 +159,5 @@ class Status():
     REPAIRING = 'Repairing'
     RUNNING = 'Running'
     VERIFYING = 'Verifying'
+
+NOTIFY_KEYS = ('startup', 'download', 'pp', 'complete', 'other')
