@@ -1056,7 +1056,8 @@ class HistoryPage(object):
                 audio = kwargs.get('audio') if kwargs.get('audio') != "-" else None                
                 flag = flag_map.get(kwargs.get('rating_flag'))
                 detail = kwargs.get('expired_host') if kwargs.get('expired_host') != '<Host>' else None
-                Rating.do.update_user_rating(kwargs.get('job'), video, audio, flag, detail) 
+                if cfg.rating_enable():
+                    Rating.do.update_user_rating(kwargs.get('job'), video, audio, flag, detail) 
         except:
             pass
         self.__edit_rating = None;
@@ -1212,7 +1213,13 @@ SWITCH_LIST = \
              'ssl_type', 'pre_script', 'pause_on_pwrar', 'ampm', 'sfv_check', 'folder_rename',
              'unpack_check', 'quota_size', 'quota_day', 'quota_resume', 'quota_period',
              'pre_check', 'max_art_tries', 'max_art_opt', 'fail_hopeless',
-             'rating_enable', 'rating_api_key', 'rating_host', 'rating_feedback',
+             'rating_enable', 'rating_api_key', 'rating_feedback', 'rating_filter_enable', 
+             'rating_filter_abort_audio', 'rating_filter_abort_video', 'rating_filter_abort_encrypted',
+             'rating_filter_abort_encrypted_confirm', 'rating_filter_abort_spam', 'rating_filter_abort_spam_confirm',
+             'rating_filter_abort_downvoted', 'rating_filter_abort_keywords',
+             'rating_filter_pause_audio', 'rating_filter_pause_video', 'rating_filter_pause_encrypted',
+             'rating_filter_pause_encrypted_confirm', 'rating_filter_pause_spam', 'rating_filter_pause_spam_confirm', 
+             'rating_filter_pause_downvoted', 'rating_filter_pause_keywords',           
              'unwanted_extensions', 'action_on_unwanted_extensions'
              )
 
@@ -1279,7 +1286,7 @@ SPECIAL_VALUE_LIST = \
               'req_completion_rate', 'wait_ext_drive', 'history_limit', 'show_sysload', 'ipv6_servers'
             )
 SPECIAL_LIST_LIST = \
-    ( 'rss_odd_titles', 'prio_sort_list'
+    ( 'rss_odd_titles', 'prio_sort_list', 'rating_host'
     )
 
 class ConfigSpecial(object):
@@ -2234,6 +2241,7 @@ class ConfigCats(object):
         for cat in sorted(categories.keys()):
             slot = categories[cat].get_dict()
             slot['name'] = cat
+            slot['newzbin'] = slot['newzbin'].replace('"', '&quot;')
             slotinfo.append(slot)
         slotinfo.insert(1, empty)
         conf['slotinfo'] = slotinfo
@@ -2581,7 +2589,7 @@ def GetRssLog(feed):
         if sabnzbd.rss.special_rss_site(url):
             nzbname = ""
         else:
-            nzbname = xml_name(sanitize_foldername(job.get('title', '')))
+            nzbname = xml_name(job.get('title', ''))
         return url, \
                title, \
                '*' * int(job.get('status', '').endswith('*')), \
@@ -2598,7 +2606,7 @@ def GetRssLog(feed):
 
     # Sort in reverse order of time stamp for 'Done'
     dnames = [job for job in jobs.keys() if jobs[job]['status'] == 'D']
-    dnames.sort(lambda x, y: jobs[y].get('timestamp', 0) - jobs[x].get('timestamp', 0))
+    dnames.sort(lambda x, y: int(jobs[y].get('time', 0) - jobs[x].get('time', 0)))
     done = [xml_name(jobs[job]['title']) for job in dnames]
 
 
