@@ -255,7 +255,9 @@ def sanitize_foldername(name, limit=True):
             lst.append(ch)
     name = ''.join(lst)
 
-    name = name.strip('. ')
+    name = name.strip()
+    if name != '.' and name != '..':
+        name = name.rstrip('.')
     if not name:
         name = 'unknown'
 
@@ -265,6 +267,26 @@ def sanitize_foldername(name, limit=True):
 
     return name
 
+#------------------------------------------------------------------------------
+def sanitize_and_trim_path(path):
+    """ Remove illegal characters and trim element size
+    """
+    path = path.strip()
+    path = path.replace('\\', '/')
+    parts = path.split('/')
+    if sabnzbd.WIN32 and len(parts[0]) == 2 and ':' in parts[0]:
+        new_path = parts[0] + '/'
+        parts.pop(0)
+    elif path.startswith('//'):
+        new_path = '//'
+    elif path.startswith('/'):
+        new_path = '/'
+    else:
+        new_path = ''
+    for part in parts:
+        new_path = os.path.join(new_path, sanitize_foldername(part))
+    return os.path.abspath(os.path.normpath(new_path))
+
 
 #------------------------------------------------------------------------------
 def flag_file(path, flag, create=False):
@@ -875,10 +897,13 @@ def get_filepath(path, nzo, filename):
         nzo.created = True
 
     fPath = os.path.join(os.path.join(path, dName), filename)
+    fPath, ext = os.path.splitext(fPath)
     n = 0
     while True:
-        fullPath = fPath
-        if n: fullPath += '.' + str(n)
+        if n:
+            fullPath = "%s.%d%s" % (fPath, n, ext)
+        else:
+            fullPath = fPath + ext
         if os.path.exists(fullPath):
             n = n + 1
         else:
@@ -1598,7 +1623,7 @@ class OrderedDict(dict):
 
     def viewitems(self):
         return ItemsView(self)
-            
+
 #------------------------------------------------------------------------------
 # A queue which ignores duplicates but maintains ordering
 class OrderedSetQueue(Queue.Queue):
