@@ -103,7 +103,10 @@ def find_programs(curdir):
         except:
             sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, 'osx/par2/par2-classic')
 
-        sabnzbd.newsunpack.RAR_COMMAND =  check(curdir, 'osx/unrar/unrar')
+        if sabnzbd.DARWIN_INTEL:
+            sabnzbd.newsunpack.RAR_COMMAND =  check(curdir, 'osx/unrar/unrar')
+        else:
+            sabnzbd.newsunpack.RAR_COMMAND =  check(curdir, 'osx/unrar/unrar-ppc')
 
     if sabnzbd.WIN32:
         if sabnzbd.WIN64 and cfg.allow_64bit_tools.get():
@@ -615,7 +618,7 @@ def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path
             msg = ('[%s] '+Ta('ERROR: CRC failed in "%s"')) % (setname, latin1(filename))
             nzo.set_unpack_info('Unpack', unicoder(msg), set=setname)
             logging.warning(Ta('ERROR: CRC failed in "%s"'), latin1(setname))
-            fail = 3
+            fail = 2 # Older unrar versions report a wrong password as a CRC error
 
         elif line.startswith('Write error'):
             nzo.fail_msg = T('Unpacking failed, write error or disk is full?')
@@ -697,7 +700,7 @@ def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path
             missing = []
             # Loop through and check for the presence of all the files the archive contained
             for path in expected_files:
-                if one_folder:
+                if one_folder or cfg.flat_unpack():
                     path = os.path.split(path)[1]
                 path = unicode2local(path)
                 if '?' in path:
@@ -1138,7 +1141,7 @@ def PAR_Verify(parfile, parfile_nzf, nzo, setname, joinables, classic=False, sin
                     nzo.fail_msg = msg
                     msg = u'[%s] %s' % (unicoder(setname), msg)
                     nzo.set_unpack_info('Repair', msg, set=setname)
-                    nzo.status = Status.FAILED
+                    nzo.status = Status.FETCHING
                     needed_blocks = avail_blocks
                     force = True
 
@@ -1589,7 +1592,7 @@ def list2cmdline(lst):
     for arg in lst:
         if not arg:
             nlst.append('""')
-        elif (' ' in arg) or ('\t' in arg) or ('&' in arg) or ('|' in arg) or (';' in arg):
+        elif (' ' in arg) or ('\t' in arg) or ('&' in arg) or ('|' in arg) or (';' in arg) or (',' in arg):
             nlst.append('"%s"' % arg)
         else:
             nlst.append(arg)
