@@ -534,7 +534,8 @@ NzbObjectMapper = (
     ('incomplete',                   'incomplete'),    # Was detected as incomplete
     ('reuse',                        'reuse'),
     ('meta',                         'meta'),          # Meta-date from 1.1 type NZB
-    ('unwanted_ext',                 'unwanted_ext')
+    ('unwanted_ext',                 'unwanted_ext'),
+    ('rating_filtered',              'rating_filtered') # Has passed through ratings filter
 )
 
 class NzbObject(TryList):
@@ -566,7 +567,7 @@ class NzbObject(TryList):
         work_name, password = scan_password(work_name)
         if not work_name:
             work_name = filename
-        if nzb and work_name:
+        if nzb and work_name and not reuse:
             work_name = sanitize_foldername(work_name)
 
         self.work_name = work_name
@@ -624,7 +625,8 @@ class NzbObject(TryList):
         self.oversized = False
         self.precheck = False
         self.incomplete = False
-        self.unwanted_ext = False
+        self.unwanted_ext = 0
+        self.rating_filtered = 0
         self.reuse = reuse
         if self.status == Status.QUEUED and not reuse:
             self.precheck = cfg.pre_check()
@@ -829,6 +831,33 @@ class NzbObject(TryList):
         else:
             self.files.sort(cmp=nzf_cmp_name)
 
+        # In the hunt for Unwanted Extensions:
+        # The file with the unwanted extension often is in the first or the last rar file
+        # So put the last rar immediatly after the first rar file so that it gets detected early
+        if cfg.unwanted_extensions() and not cfg.auto_sort():
+            # ... only useful if there are unwanted extensions defined and there is no sorting on date
+            logging.debug('Unwanted Extension: putting last rar after first rar')
+            nzfposcounter = firstrarpos = lastrarpos = 0
+            for nzf in self.files:
+                nzfposcounter += 1
+                if '.rar' in str(nzf):
+                    # a NZF found with '.rar' in the name
+                    if firstrarpos == 0:
+                        # this is the first .rar found, so remember this position
+                        firstrarpos = nzfposcounter
+                    lastrarpos = nzfposcounter
+                    lastrarnzf = nzf    # The NZF itself
+
+            if firstrarpos != lastrarpos:
+                # at least two different .rar's found
+                logging.debug('Unwanted Extension: First rar at %s, Last rar at %s',firstrarpos, lastrarpos)
+                logging.debug('Unwanted Extension: Last rar is %s', str(lastrarnzf))
+                try:
+                    self.files.remove(lastrarnzf)        # first remove. NB: remove() does searches for lastrarnzf
+                    self.files.insert(firstrarpos,lastrarnzf)    # ... and only then add after position firstrarpos
+                except:
+                    logging.debug('The lastrar swap did not go well')
+
         # Set nzo save-delay to 6 sec per GB with a max of 5 min
         self.save_timeout = min(6.0 * float(self.bytes) / GIGI, 300.0)
 
@@ -1043,6 +1072,8 @@ class NzbObject(TryList):
             prefix += Ta('INCOMPLETE') + ' / ' #: Queue indicator for incomplete NZB
         if self.unwanted_ext and self.status == 'Paused':
             prefix += Ta('UNWANTED') + ' / ' #: Queue indicator for unwanted extensions
+        if self.rating_filtered and self.status == 'Paused':
+            prefix += Ta('FILTERED') + ' / ' #: Queue indicator for filtered
         if isinstance(self.wait, float):
             dif = int(self.wait - time.time() + 0.5)
             if dif > 0:
@@ -1080,11 +1111,16 @@ class NzbObject(TryList):
         if self.encrypted:
             # If user resumes after encryption warning, no more auto-pauses
             self.encrypted = 2
+        if self.rating_filtered:
+            # If user resumes after filtered warning, no more auto-pauses
+            self.rating_filtered = 2
         # If user resumes after warning, reset duplicate/oversized/incomplete/unwanted indicators
         self.duplicate = False
         self.oversized = False
         self.incomplete = False
-        self.unwanted_ext = False
+        if self.unwanted_ext:
+            # If user resumes after "unwanted" warning, no more auto-pauses
+            self.unwanted_ext = 2
 
     def add_parfile(self, parfile):
         if parfile not in self.files:
@@ -1274,16 +1310,20 @@ class NzbObject(TryList):
     # Determine if rating information (including site identifier so rating can be updated)
     # is present in metadata and if so store it
     def update_rating(self):
-        try:
-            def _get_first_meta(type):
-                values = self.meta.get('x-rating-' + type, None)
-                return values[0] if values else None
-            rating_types = ['id', 'video', 'videocnt', 'audio', 'audiocnt', 'voteup' ,'votedown']
-            rs = map(_get_first_meta, rating_types)
-            Rating.do.add_rating(rs[0], self.nzo_id, rs[1], rs[2], rs[3], rs[4], rs[5], rs[6])
-        except:
-            pass
-                           
+        if cfg.rating_enable():
+            try:
+                def _get_first_meta(type):
+                    values = self.meta.get('x-oznzb-rating-' + type, None) or self.meta.get('x-rating-' + type, None)
+                    return values[0] if values else None
+                rating_types = ['video', 'videocnt', 'audio', 'audiocnt', 'voteup' ,'votedown', \
+                                'spam', 'confirmed-spam', 'passworded', 'confirmed-passworded']
+                fields = {}
+                for k in rating_types:
+                    fields[k] = _get_first_meta(k)
+                Rating.do.add_rating(_get_first_meta('id'), self.nzo_id, self.meta.get('x-rating-host'), fields)
+            except:
+                pass
+
     ## end nzo.Mutators #######################################################
     ###########################################################################
     @property
