@@ -31,7 +31,7 @@ import re
 from sabnzbd.newsunpack import unpack_magic, par2_repair, external_processing, sfv_check
 from threading import Thread
 from sabnzbd.misc import real_path, get_unique_path, create_dirs, move_to_path, \
-                         make_script_path, \
+                         make_script_path, sanitize_and_trim_path, \
                          on_cleanup_list, renamer, remove_dir, remove_all, globber, \
                          set_permissions, cleanup_empty_directories
 from sabnzbd.tvsort import Sorter
@@ -321,6 +321,8 @@ def process_job(nzo):
             if file_sorter.sort_file:
                 one_folder = False
 
+            complete_dir = sanitize_and_trim_path(complete_dir)
+
             if one_folder:
                 workdir_complete = create_dirs(complete_dir)
             else:
@@ -487,13 +489,14 @@ def process_job(nzo):
         all_ok = all_ok and not empty
 
         ## Update indexer with results
-        if nzo.encrypted > 0:
-            Rating.do.update_auto_flag(nzo.nzo_id, Rating.FLAG_ENCRYPTED)
-        if empty:
-            hosts = map(lambda s: s.host, sabnzbd.downloader.Downloader.do.nzo_servers(nzo))
-            if not hosts: hosts = [None]
-            for host in hosts:
-                Rating.do.update_auto_flag(nzo.nzo_id, Rating.FLAG_EXPIRED, host)
+        if cfg.rating_enable():
+            if nzo.encrypted > 0:
+                Rating.do.update_auto_flag(nzo.nzo_id, Rating.FLAG_ENCRYPTED)
+            if empty:
+                hosts = map(lambda s: s.host, sabnzbd.downloader.Downloader.do.nzo_servers(nzo))
+                if not hosts: hosts = [None]
+                for host in hosts:
+                    Rating.do.update_auto_flag(nzo.nzo_id, Rating.FLAG_EXPIRED, host)
 
         ## Show final status in history
         if all_ok:
@@ -632,7 +635,7 @@ def try_sfv_check(nzo, workdir, setname):
     par_error = False
     found = False
     for sfv in sfvs:
-        if setname in os.path.basename(sfv):
+        if setname.lower() in os.path.basename(sfv).lower():
             found = True
             nzo.set_unpack_info('Repair', T('Trying SFV verification'))
             failed = sfv_check(sfv)
