@@ -396,11 +396,7 @@ class RSSQueue(object):
 
             if link:
                 # Make sure spaces are quoted in the URL
-                if 'nzbclub.com' in link:
-                    link, path = os.path.split(link.strip())
-                    link = '%s/%s' % (link, urllib.quote(path))
-                else:
-                    link = link.strip().replace(' ','%20')
+                link = link.strip().replace(' ','%20')
 
                 newlinks.append(link)
 
@@ -592,7 +588,7 @@ def _HandleLink(jobs, link, title, flag, orgcat, cat, pp, script, download, star
     if special_rss_site(link):
         nzbname = None
     else:
-        nzbname = sanitize_foldername(title)
+        nzbname = title
     m = RE_NEWZBIN.search(link)
     if m and m.group(1).lower() == 'newz' and m.group(2) and m.group(3):
         if download:
